Technical Documentation: jonas/tig
โน๏ธ Provenance: Multi-Tier Ingestion ยท CodeWiki Reference
Doc Manual (`doc/manual.adoc`)
ifndef::doctype-manpage[] The Tig Manual
Jonas Fonseca [email protected]
endif::doctype-manpage[]
This is the manual for Tig, the ncurses-based text-mode interface for git.
Tig allows you to browse changes in a Git repository and can additionally act
as a pager for output of various Git commands. When used as a pager, it will
display input from stdin and colorize it.
When browsing repositories, Tig uses the underlying Git commands to present
the user with various views, such as summarized commit log and showing the
commit with the log message, diffstat, and the diff.
ifdef::include-manual-toc[]
Table of Contents
include::manual.toc[]
endif::include-manual-toc[]
[[calling-conventions]] Calling Conventions
[[pager-mode]]
Pager Mode
If stdin is a pipe, any log or diff options will be ignored and the pager view
will be opened loading data from stdin. The pager mode can be used for
colorizing output from various Git commands.
Example on how to colorize the output of git-show(1):
-----------------------------------------------------------------------------
$ git show | tig
-----------------------------------------------------------------------------
[[cmd-options]]
Git Command OptionsAll Git command options specified on the command line will be passed to the
given command and all will be shell quoted before they are passed to the
shell.
NOTE: If you specify options for the main view, you should not use the--pretty option as this option will be set automatically to the format
expected by the main view.
Example on how to view a commit and show both author and committer
information:
$ tig show --pretty=fuller
See the section on <<refspec, specifying revisions>> for an introduction to
revision options supported by the Git commands. For details on specific Git
command options, refer to the man page of the command in question.
[[viewer]] The Viewer
The display consists of a status window on the last line of the screen and one
or more views. The default is to only show one view at a time but it is
possible to split both the main and log view to also show the commit diff.
If you are in the log view and press 'Enter' when the current line is a commit
line, such as:
commit 4d55caff4cc89335192f3e566004b4ceef572521
You will split the view so that the log view is displayed in the top window
and the diff view in the bottom window. You can switch between the two views
by pressing 'Tab'. To maximize the log view again, simply press 'l'.
[[views]]
Views
Various 'views' of a repository are presented. Each view is based on output
from an external command, most often 'git log', 'git diff', or 'git show'.
The main view::
Is the default view, and it shows a one line summary of each commit
in the chosen list of revisions. The summary includes committer or
author date, author, committer, and the first line of the log message.
Additionally, any repository references, such as tags, will be shown.
The log view::
Presents a richer view of the revision log showing the whole log
message and the diffstat.
The reflog view::
Presents a view of the reflog allowing navigation of the repo
history.
The diff view::
Shows either the diff of the current working tree, that is, what
has changed since the last commit, or the commit diff complete
with log message, diffstat and diff.
The tree view::
Lists directory trees associated with the current revision allowing
subdirectories to be descended or ascended and file blobs to be
viewed.
The blob view::
Displays the file content or "blob" of data associated with a file
name.
The blame view::
Displays the file content annotated or blamed by commits.
The refs view::
Displays the branches, remotes and tags in the repository.
The status view::
Displays status of files in the working tree and allows changes to be
staged/unstaged as well as adding of untracked files.
The stage view::
Displays diff changes for staged or unstaged files being tracked or
file content of untracked files.
The stash view::
Displays the list of stashes in the repository.
The grep view::
Displays a list of files and all the lines that match a search
pattern.
The pager view::
Is used for displaying both input from stdin and output from Git
commands entered in the internal prompt.
The help view::
Displays a quick reference of key bindings.
[[commit-id]]
Browsing State and User-defined CommandsThe viewer keeps track of both what head and commit ID you are currently
viewing. The commit ID will follow the cursor line and change every time you
highlight a different commit. Whenever you reopen the diff view it will be
reloaded, if the commit ID changed. The head ID is used when opening the main
and log view to indicate from what revision to show history.
Some of the commands used or provided by Tig can be configured. This goes for
some of the <<env-variables, environment variables>> as well as the
<<external-commands, external commands>>. These user-defined commands can use
arguments that refer to the current browsing state by using one of the
following variables.
.Browsing state variables
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|%(head) |The currently viewed 'head' ID. Defaults to HEAD
|%(commit) |The currently selected commit ID.
|%(blob) |The currently selected blob ID.
|%(branch) |The currently selected branch name.
|%(remote) |The currently selected remote name. For remote
branches %(branch) will contain the branch name.
|%(tag) |The currently selected tag name.
|%(refname) |The currently selected reference name including the
remote name for remote branches.
|%(stash) |The currently selected stash name.
|%(directory) |The current directory path in the tree view or
"." if undefined.
|%(file) |The currently selected file.
|%(file_old) |The old filename of the currently selected file.
|%(lineno) |The currently selected line number. Defaults to 0.
|%(lineno_old) |The currently selected line number, before the diff
was applied. Defaults to 0.
|%(ref) |The reference given to blame or HEAD if undefined.
|%(revargs) |The revision arguments passed on the command line.
|%(fileargs) |The file arguments passed on the command line.
|%(cmdlineargs) |All other options passed on the command line.
|%(diffargs) |Options from 'diff-options' or 'TIG_DIFF_OPTS' used
by the diff and stage view.
|%(blameargs) |Options from 'blame-options' used by the blame view.
|%(logargs) |Options from 'log-options' used by the log view.
|%(mainargs) |Options from 'main-options' used by the main view.
|%(prompt) |Prompt for the argument value. Optionally specify a
custom prompt using "%(prompt Enter branch name: )"
|%(text) |The text column of the currently selected line.
|%(repo:head) |The name of the checked out branch, e.g. master
|%(repo:head-id) |The commit ID of the checked out branch.
|%(repo:remote) |The remote name associated with the checked out
branch, e.g. origin.
|%(repo:upstream) |The upstream branch associated with the checked out
branch, e.g. origin/master.
|%(repo:cdup) |The path to change directory to the repository root,
e.g. ../
|%(repo:prefix) |The path prefix of the current work directory,
e.g. subdir/.
|%(repo:git-dir) |The path to the Git directory, e.g. /src/repo/.git.
|%(repo:worktree) |The worktree path, if defined.
|%(repo:is-inside-work-tree)
|Whether Tig is running inside a work tree,
either true or false.
|=============================================================================
Example user-defined commands:
Allow amending the last commit:
bind generic + !git commit --amend
Copy commit ID to clipboard:
bind generic 9 @sh -c "echo -n %(commit) | xclip -selection c"
Add/edit notes for the current commit used during a review:
bind generic T !git notes edit %(commit)
Enter Git's interactive add for fine-grained staging of file content:
bind generic I !git add -i %(file)
Rebase current branch on top of the selected branch:
bind refs 3 !git rebase -i %(branch)
[[title-window]]
Title Windows
Each view has a title window which shows the name of the view, current commit
ID if available, and where the view is positioned:
-------------------------------------------------------------------------------
[main] c622eefaa485995320bc743431bae0d497b1d875 - commit 1 of 61 1%
-------------------------------------------------------------------------------
By default, the title of the current view is highlighted using bold font. For
long loading views (taking over 3 seconds) the time since loading started will
be appended:
-------------------------------------------------------------------------------
[main] 77d9e40fbcea3238015aea403e06f61542df9a31 - commit 1 of 779 loading 5s 0%
-------------------------------------------------------------------------------
[[env-variables]]
Environment Variables
---------------------
Several options related to the interface with Git can be configured via
environment variables.
[[configuration-files]]
Configuration FilesUpon startup, Tig first reads the system wide configuration file
({sysconfdir}/tigrc by default) and then proceeds to read the user's
configuration file (~/.tigrc or $XDG_CONFIG_HOME/tig/config by default).
The paths to either of these files can be overridden through the following
environment variables:
TIGRC_USER::
Path of the user configuration file.
TIGRC_SYSTEM::
Path of the system wide configuration file.
[[history-files]]
History Files
If compiled with readline support, Tig writes a persistent command and search
history to `~/.tig_history` or `$XDG_DATA_HOME/tig/history`.
[[repo-refs]]
Repository ReferencesCommits that are referenced by tags and branch heads will be marked by the
reference name surrounded by '[' and ']':
2006-03-26 19:42 Petr Baudis | [cogito-0.17.1] Cogito 0.17.1
If you want to limit what branches are shown, say only show branches namedmaster or those which start with the feature/ prefix, you can do it by setting
the following variable:
$ TIG_LS_REMOTE="git ls-remote . master feature/*" tig
Or set the variable permanently in your environment.
--
TIG_LS_REMOTE::
Command for retrieving all repository references. The command should
output data in the same format as git-ls-remote(1). Defaults to:git ls-remote .
--
[[diff-options]]
Diff options
It is possible to alter how diffs are shown by the diff view. If for example
you prefer to have commit and author dates shown as relative dates, use:
-----------------------------------------------------------------------------
$ TIG_DIFF_OPTS="--relative-date" tig
-----------------------------------------------------------------------------
Or set the variable permanently in your environment.
[[keys]]
Default Keybindings
-------------------
Below the default key bindings are shown.
[[view-switching]]
View Switching[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|m |Switch to main view.
|d |Switch to diff view.
|l |Switch to log view.
|p |Switch to pager view.
|t |Switch to (directory) tree view.
|f |Switch to (file) blob view.
|g |Switch to grep view.
|b |Switch to blame view.
|r |Switch to refs view.
|y |Switch to stash view.
|h |Switch to help view
|s |Switch to status view
|c |Switch to stage view
|=============================================================================
[[view-manipulation]]
View Manipulation
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|q |Close view, if multiple views are open it will jump back to the
previous view in the view stack. If it is the last open view it
will quit. Use 'Q' to quit all views at once.
|Enter |This key is "context sensitive" depending on what view you are
currently in. When in log view on a commit line or in the main
view, split the view and show the commit diff. In the diff view
pressing Enter will simply scroll the view one line down.
|Tab |Switch to next view.
|R |Reload and refresh the current view.
|O |Maximize the current view to fill the whole display.
|Up |This key is "context sensitive" and will move the cursor one
line up. However, if you opened a split view it will change the
cursor to point to the previous commit in the parent view and
update the child view to display it. If you prefer this key to
move the cursor or scroll within the diff view instead,
use `bind diff <Up> move-up` or `bind diff <Up> scroll-line-up`,
respectively.
|Down |Similar to 'Up' but will move down.
|, |Move to parent. In the tree view, this means switch to the parent
directory. In the blame view it will load blame for the parent
commit. For merges the parent is queried.
|=============================================================================
[[view-actions]]
View Specific Actions[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|u |Update status of file. In the status view, this allows you to add an
untracked file or stage changes to a file for next commit (similar to
running git-add
a diff chunk line stages only that chunk for next commit, when not on
a diff chunk line all changes in the displayed diff are staged.
|M |Resolve unmerged file by launching git-mergetool(1). Note, to work
correctly this might require some initial configuration of your
preferred merge tool. See the manpage of git-mergetool(1).
|! |Checkout file with unstaged changes. This will reset the file to
contain the content it had at the last commit.
|1 |Stage single diff line.
|@ |Move to next chunk in the stage view.
|] |Increase the diff context.
|[ |Decrease the diff context.
|=============================================================================
[[cursor-nav]]
Cursor Navigation
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|k |Move cursor one line up.
|j |Move cursor one line down.
|PgUp, - |Move cursor one page up.
|PgDown, Space |Move cursor one page down.
|Home |Jump to first line.
|End |Jump to last line.
|=============================================================================
[[view-scrolling]]
Scrolling
~~~~~~~~~
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|Insert |Scroll view one line up.
|Delete |Scroll view one line down.
|ScrollBack |Scroll view one page up.
|ScrollFwd |Scroll view one page down.
|Left |Scroll view one column left.
|Right |Scroll view one column right.
|\| |Scroll view to the first column.
|=============================================================================
[[searching]]
Searching
~~~~~~~~~
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|/ |Search the view. Opens a prompt for entering search regexp to use.
|? |Search backwards in the view. Also prompts for regexp.
|n |Find next match for the current search regexp.
|N |Find previous match for the current search regexp.
|=============================================================================
The format for patterns is either POSIX.2 ``extended'' REs or PCRE / PCRE2 if
Tig was compiled with PCRE / PCRE2 support (check with `tig -v`). See the
manpage of re_format(7) or pcrepattern(3) / pcre2pattern(3).
Case sensitivity can be controlled with variable ignore-case.
[[misc-keys]]
Misc
~~~~
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|Q |Quit.
|<C-L> |Redraw screen.
|z |Stop all background loading. This can be useful if you use
Tig in a repository with a long history without limiting
the revision log.
|v |Show version.
|o |Open option menu
|# |Toggle line numbers on/off.
|D |Toggle date display on/off/relative/relative-compact/custom
|A |Toggle author display on/off/abbreviated/email/email user name.
|T |Toggle committer display on/off/abbreviated/email/email user name.
|G |Toggle revision graph visualization on/off.
|~ |Toggle (line) graphics mode
|F |Toggle reference display on/off (tag and branch names).
|W |Toggle ignoring whitespace on/off for diffs
|X |Toggle commit ID display on/off
|% |Toggle file filtering in order to see the full diff instead of only
the diff concerning the currently selected file.
|^ |Toggle revision filtering in the main view.
|$ |Toggle highlighting of commit title overflow.
|H |Go to the HEAD commit.
|: |Open prompt. This allows you to specify what command to run and also to
jump to a specific line, e.g. `:23`
|e |Open file in editor.
|=============================================================================
[[prompt]]
Prompt
~~~~~~
[frame="none",grid="none",cols="2<,8<",options="header"]
|=============================================================================
|Key |Action
|:<number> |Jump to the specific line number, e.g. `:80`.
|:<sha> |Jump to a specific commit, e.g. `:2f12bcc`.
|:<x> |Execute the corresponding key binding, e.g. `:q`.
|:!<command> |Execute a system command in a pager, e.g. `:!git log -p`.
|:<action> |Execute a Tig command, e.g. `:edit`.
|:goto <rev> |Jump to a specific revision, e.g. `:goto %(commit)^2`
to go to the current commit's 2nd parent or
`:goto some/branch` to go to the commit denoting the
branch `some/branch`.
|:save-display <file> |Save current display to `<file>`.
|:save-options <file> |Save current options to `<file>`.
|:save-view <file> |Save view info to `<file>` (for testing purposes).
|:script <file> |Execute commands from `<file>`.
|:exec <flags><args...> |Execute command using `<args>` with external
user-defined command option flags defined in `<flags>`.
|:echo <args...> |Display text in the status bar.
|=============================================================================
[[external-commands]]
External CommandsFor more custom needs, external commands provide a way to easily execute
a script or program. They are bound to keys and use information from the
current browsing state, such as the current commit ID. Tig comes with
the following built-in external commands:
[frame="none",grid="none",cols="1<,1<,8<",options="header"]
|=============================================================================
|Keymap |Key |Action
|main |C |git cherry-pick %(commit)
|status |C |git commit
|generic|G |git gc
|=============================================================================
[[refspec]] Revision Specification
This section describes various ways to specify what revisions to display or
otherwise limit the view to. Tig does not itself parse the described
revision options so refer to the relevant Git man pages for further
information. Relevant man pages besides git-log(1) are git-diff(1) and
git-rev-list(1).
You can tune the interaction with Git by making use of the options explained
in this section. For example, by configuring the environment variable
described in the section on <<diff-options, diff options>>.
[[path-limiting]]
Limit by Path Name
If you are interested only in those revisions that made changes to a specific
file (or even several files) list the files like this:
-----------------------------------------------------------------------------
$ tig Makefile README
-----------------------------------------------------------------------------
To avoid ambiguity with Tig's subcommands or repository references such as tag
names, be sure to separate file names from other Git options using "`--`". So
if you have a file named 'status' it will clash with the 'status' subcommand,
and thus you will have to use:
-----------------------------------------------------------------------------
$ tig -- status
-----------------------------------------------------------------------------
[[date-number-limiting]]
Limit by Date or NumberTo speed up interaction with Git, you can limit the number of commits to show
both for the log and main view. Either limit by date using e.g.--since=1.month or limit by the number of commits using -n400.
If you are only interested in changes that happened between two dates you can
use:
$ tig --after="May 5th" --before="2006-05-16 15:44"
NOTE: If you want to avoid having to quote dates containing spaces you can use
"." instead, e.g. --after=May.5th.
[[commit-range-limiting]]
Limiting by Commit Ranges
Alternatively, commits can be limited to a specific range, such as "all
commits between 'tag-1.0' and 'tag-2.0'". For example:
-----------------------------------------------------------------------------
$ tig tag-1.0..tag-2.0
-----------------------------------------------------------------------------
This way of commit limiting makes it trivial to only browse the commits which
haven't been pushed to a remote branch. Assuming 'origin' is your upstream
remote branch, using:
-----------------------------------------------------------------------------
$ tig origin..HEAD
-----------------------------------------------------------------------------
will list what will be pushed to the remote branch. Optionally, the ending
'HEAD' can be left out since it is implied.
[[reachability-limiting]]
Limiting by Reachability
~~~~~~~~~~~~~~~~~~~~~~~~
Git interprets the range specifier "tag-1.0..tag-2.0" as "all commits
reachable from 'tag-2.0' but not from 'tag-1.0'", where reachability refers
to what commits are ancestors (or part of the history) of the branch or tagged
revision in question.
If you prefer to specify which commit to preview in this way use the
following:
-----------------------------------------------------------------------------
$ tig tag-2.0 ^tag-1.0
-----------------------------------------------------------------------------
You can think of '^' as a negation operator. Using this alternate syntax, it
is possible to further prune commits by specifying multiple branch cut offs.
[[refspec-combi]]
Combining Revision SpecificationsRevision options can to some degree be combined, which makes it possible to
say "show at most 20 commits from within the last month that changed files
under the Documentation/ directory."
$ tig --since=1.month -n20 -- Documentation/
[[refspec-all]]
Examining All Repository References
In some cases, it can be useful to query changes across all references in a
repository. An example is to ask "did any line of development in this
repository change a particular file within the last week". This can be
accomplished using:
-----------------------------------------------------------------------------
$ tig --all --since=1.week -- Makefile
-----------------------------------------------------------------------------
More Information
----------------
Please visit Tig's https://github.com/jonas/tig[home page] for information
about new releases and how to report bugs and feature requests.
[[copy-right]]
Copyright
---------
Copyright (c) 2006-2026 Jonas Fonseca <[email protected]>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
[[references]]
See Also
--------
Manpages:
ifdef::version[]
- manpage:tig[1]
- manpage:tigrc[5]
endif::version[]
ifndef::version[]
- link:tig.1.adoc[tig(1)]
- link:tigrc.5.adoc[tigrc(5)]
endif::version[]
---
### Doc Tig.1 (`doc/tig.1.adoc`)
tig(1)
======
:docext: adoc
:sysconfdir: /etc
NAME
----
tig - text-mode interface for Git
SYNOPSIS
--------
[verse]
_______________________________________________________________________
tig [options] [revisions] [--] [paths]
tig log [options] [revisions] [--] [paths]
tig show [options] [revisions] [--] [paths]
tig reflog [options] [revisions]
tig blame [options] [rev] [--] path
tig grep [options] [pattern]
tig refs [options]
tig stash [options]
tig status
tig < [Git command output]
_______________________________________________________________________
DESCRIPTION
-----------
Tig is an ncurses-based text-mode interface for git(1). It functions
mainly as a Git repository browser, but can also assist in staging
changes for commit at chunk level and act as a pager for output from
various Git commands.
OPTIONS
-------
Command line options recognized by Tig include all valid git-log(1) and
git-diff(1) options, as well as the following subcommands and Tig-specific
options. The first command line parameter not starting with "-" is interpreted
as being either a revision specification or a path and will end the option
parsing. All additional options will be passed to the underlying Git command.
Note that this means that any arguments to options should be specified
together. For example, run tig -Sfoo instead of tig -S foo, and tig --grep=foo
instead of tig --grep foo, otherwise foo will be interpreted as a revision
rather than an argument.
show::
Open diff view using the given git-show(1) options.
blame::
Show given file annotated by commits.
Takes zero or more git-blame(1) options.
Optionally limited from given revision.
status::
Start up in status view.
log::
Start up in log view, displaying git-log(1) output.
reflog::
Start up in reflog view.
refs::
Start up in refs view. All refs are displayed unless limited by using
one of the '--branches', '--remotes', or '--tags' parameters.
stash::
Start up in stash view.
grep::
Open the grep view. Supports the same options as git-grep(1).
+<number>::
Show the first view with line <number> visible and selected.
-v, --version::
Show version and exit.
-h, --help::
Show help message and exit.
-C ::
Run as if Tig was started in instead of the current working directory.
PAGER MODE
----------
Tig enters pager mode when input is provided via stdin and supports the
following subcommands and options:
--
- When the 'show' subcommand is specified and the '--stdin' option is given,
stdin is assumed to be a list of commit IDs and will be forwarded to the diff
view's underlying git-show(1) command. For example:
-----------------------------------------------------------------------------
$ git rev-list --author=vivien HEAD | tig show --stdin
-----------------------------------------------------------------------------
- When '--stdin' is given, stdin is assumed to be a list of commit IDs
and will be forwarded to the main view's underlying git-log(1)
command. For example:
-----------------------------------------------------------------------------
$ tig --no-walk --stdin < cherry-picks.txt
-----------------------------------------------------------------------------
- When '--pretty=raw' is given, stdin is assumed to be a "pretty=raw"
formatted output similar to that of git-log(1). For example:
-----------------------------------------------------------------------------
$ git reflog --pretty=raw | tig --pretty=raw
-----------------------------------------------------------------------------
--
When no subcommands nor options are given, the pager view will be used for
displaying the Git command input given on stdin. The pager view assumes the
input is either from git-log(1) or git-diff(1) and will highlight it similar to
the log and diff views. For example:
-----------------------------------------------------------------------------
$ git log -Schange -p --raw | tig
-----------------------------------------------------------------------------
EXAMPLES
--------
Display the list of commits for the current branch:
-----------------------------------------------------------------------------
$ tig
-----------------------------------------------------------------------------
Display commits from one or more branches:
-----------------------------------------------------------------------------
$ tig test master
-----------------------------------------------------------------------------
Pretend as if all the refs in `refs/` are listed on the command line:
-----------------------------------------------------------------------------
$ tig --all
-----------------------------------------------------------------------------
Display differences between two branches:
-----------------------------------------------------------------------------
$ tig test..master
-----------------------------------------------------------------------------
Display changes for sub-module versions:
-----------------------------------------------------------------------------
$ tig --submodule
-----------------------------------------------------------------------------
Display changes for a single file:
-----------------------------------------------------------------------------
$ tig -- README
-----------------------------------------------------------------------------
Display contents of the README file in a specific revision:
-----------------------------------------------------------------------------
$ tig show tig-0.8:README
-----------------------------------------------------------------------------
Display revisions between two dates for a specific file:
-----------------------------------------------------------------------------
$ tig --after="2004-01-01" --before="2006-05-16" -- README
-----------------------------------------------------------------------------
Blame file with copy detection enabled:
-----------------------------------------------------------------------------
$ tig blame -C README
-----------------------------------------------------------------------------
Display the list of stashes:
-----------------------------------------------------------------------------
$ tig stash
-----------------------------------------------------------------------------
Grep all files for lines containing `DEFINE_ENUM`:
-----------------------------------------------------------------------------
$ tig grep -p DEFINE_ENUM
-----------------------------------------------------------------------------
Show references (branches, remotes and tags):
-----------------------------------------------------------------------------
$ tig refs
-----------------------------------------------------------------------------
Use word diff in the diff view:
-----------------------------------------------------------------------------
$ tig --word-diff=plain
-----------------------------------------------------------------------------
ENVIRONMENT VARIABLES
---------------------
In addition to environment variables used by Git (e.g. GIT_DIR), Tig defines
the ones below. The command related environment variables have access to the
internal state of Tig via replacement variables, such as `%(commit)` and
`%(blob)`.
ifdef::version[]
See manpage:tigrc[5] for a full list.
endif::version[]
ifndef::version[]
See link:tigrc.5.{docext}[tigrc(5)] for a full list.
endif::version[]
TIGRC_USER::
Path of the user configuration file (defaults to `~/.tigrc` or
`$XDG_CONFIG_HOME/tig/config`).
TIGRC_SYSTEM::
Path of the system wide configuration file (defaults to
`{sysconfdir}/tigrc`). Define to empty string to use built-in
configuration.
TIG_LS_REMOTE::
Command for retrieving all repository references. The command
should output data in the same format as git-ls-remote(1).
TIG_DIFF_OPTS::
The diff options to use in the diff view. The diff view uses
git-show(1) for formatting and always passes --patch-with-stat. You
may also set the `diff-options` setting in the configuration file.
TIG_TRACE::
Path for trace file where information about Git commands is logged.
TIG_SCRIPT::
Path to script that should be executed automatically on startup. If this
environment variable is defined to the empty string, the script is read
from stdin. The script is interpreted line-by-line and can contain
prompt commands and key mappings. Note that the '<' character must be
encoded as '<LT>' within the script.
E.g. TIG_SCRIPT=<(echo :set main-view-commit-title-graph = no) tig
TIG_NO_DISPLAY::
Open Tig without rendering anything to the terminal. This forces Ncurses
to write to /dev/null. The main use is for automated testing of Tig.
TIG_EDITOR::
The editor command to use when visiting files. This environment
variable overrides (in order of precedence) '$GIT_EDITOR',
'core.editor' configuration, '$VISUAL' and '$EDITOR', so it
allows using a different editor from the one Git uses. The
value is meant to be interpreted by the shell when it is used.
FILES
-----
'$XDG_CONFIG_HOME/tig/config'::
'~/.config/tig/config'::
'~/.tigrc'::
The Tig user configuration file is loaded in the following way. If
`$XDG_CONFIG_HOME` is set, read user configuration from
`$XDG_CONFIG_HOME/tig/config`. If `$XDG_CONFIG_HOME` is empty or
undefined, read user configuration from `~/.config/tig/config` if it
exists and fall back to `~/.tigrc` if it does not exist. See
manpage:tigrc[5] for examples.
'{sysconfdir}/tigrc'::
System wide configuration file.
'$GIT_DIR/config'::
'~/.gitconfig'::
'{sysconfdir}/gitconfig'::
Git configuration files. Read on start-up with the help of
git-config(1).
'$XDG_DATA_HOME/tig/history'::
'~/.local/share/tig/history'::
'~/.tig_history'::
When compiled with readline support, Tig writes a persistent command and
search history. The location of the history file is determined in the
following way. If `$XDG_DATA_HOME` is set and `$XDG_DATA_HOME/` exists,
create `$XDG_DATA_HOME/tig/` if needed and store history to
`$XDG_DATA_HOME/tig/history`. If `$XDG_DATA_HOME` is empty or undefined,
store history to `~/.local/share/tig/history` if the directory
`~/.local/share/tig/` exists, and fall back to `~/.tig_history` if it
does not exist.
BUGS
----
Please visit Tig's https://github.com/jonas/tig[home page] for information
about new releases and how to report bugs or feature requests.
COPYRIGHT
---------
Copyright (c) 2006-2026 Jonas Fonseca <[email protected]>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
SEE ALSO
--------
ifndef::backend-docbook[]
link:tigrc.5.{docext}[tigrc(5)],
link:manual.{docext}[the Tig manual],
endif::backend-docbook[]
ifdef::backend-docbook[]
manpage:tigrc[5],
manpage:tigmanual[7],
endif::backend-docbook[]
git(1)
---
### Doc Tigmanual.7 (`doc/tigmanual.7.adoc`)
tigmanual(7)
============
NAME
----
tigmanual - text-mode interface for Git
SYNOPSIS
--------
[verse]
tig [options] [revisions] [--] [paths]
tig show [options] [revisions] [--] [paths]
tig blame [options] [rev] [--] path
tig status
tig < [Git command output]
DESCRIPTION
-----------
include::manual.adoc[]
---
### Doc Tigrc.5 (`doc/tigrc.5.adoc`)
tigrc(5)
========
:docext: adoc
NAME
----
tigrc - Tig configuration file
SYNOPSIS
--------
[verse]
_______________________________________________________________________
*set* 'variable' *=* 'value'
*bind* 'keymap' 'key' 'action'
*color* 'area' 'fgcolor' 'bgcolor' '[attributes]'
*source* 'path'
_______________________________________________________________________
DESCRIPTION
-----------
You can permanently set an option by putting it in the `~/.tigrc` file. The
file consists of a series of 'commands'. Each line of the file may contain
only one command. Commands can span multiple lines if each line is
terminated by a backslash ('\') character.
The hash mark ('#') is used as a 'comment' character. All text after the
comment character to the end of the line is ignored. You can use comments to
annotate your initialization file.
Certain options can be manipulated at runtime via the option menu. In
addition, options can also be toggled with the `:toggle` prompt command
or by entering the configuration command into the prompt.
In some environments, a user's configuration will be stored in the alternate
location `$XDG_CONFIG_HOME/tig/config`. For brevity, this document will
refer only to `~/.tigrc`.
Git configuration
-----------------
Alternatively to using `~/.tigrc`, Tig options can be set by putting them in
one of the Git configuration files, which are read by Tig on startup. See
'git-config(1)' for which files to use. The following example shows the basic
syntax to use for settings, bindings and colors.
// TEST: gitconfig
--------------------------------------------------------------------------
[tig] show-changes = true
[tig "color"] cursor = yellow red bold
[tig "bind"] generic = P parent
--------------------------------------------------------------------------
In addition to tig-specific options, the following Git options are read from
the Git configuration:
'color.*'::
Colors for the various UI types. Can be configured via the 'git-colors'
setting.
'core.abbrev'::
The width of the commit ID. See also 'id-width' option.
'core.editor'::
The editor command. Can be overridden by setting TIG_EDITOR or
GIT_EDITOR.
'core.worktree'::
The path to the root of the working tree.
'gui.encoding'::
The encoding to use for displaying file content.
'i18n.commitencoding'::
The encoding used for commits. The default is UTF-8.
Set command
-----------
A few selective variables can be configured via the set command. The syntax
is:
[verse]
*set* variable *=* value
Use *+=* to append value to a string variable.
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
set commit-order = topo # Order commits topologically
set git-colors = no # Do not read Git's color settings.
set horizontal-scroll = 33% # Scroll 33% of the view width
set blame-options = -C -C -C # Blame lines from other files
set log-options += --minimal # Use minimal diff algorithm
# Wrap branch names with () and tags with <>
set reference-format = (branch) <tag>
# Configure blame view columns using command spanning multiple lines.
set blame-view = \
date:default \
author:abbreviated \
committer:abbreviated \
file-name:auto \
id:yes,color \
line-number:yes,interval=5 text
--------------------------------------------------------------------------
Or in the Git configuration files:
// TEST: gitconfig
--------------------------------------------------------------------------
[tig]
line-graphics = no # Disable graphics characters
tab-size = 8 # Number of spaces per tab
--------------------------------------------------------------------------
The type of variables is either bool, int, string, or mixed.
Valid bool values::
To set a bool variable to true use either "1", "true", or "yes".
Any other value will set the variable to false.
Valid int values::
A non-negative integer.
Valid string values::
A string of characters. Optionally, use either ' or " as delimiters.
Valid mixed values::
These values are composites of the above types. The valid values are
specified in the description.
Variables
~~~~~~~~~
The following variables can be set:
'diff-options' (string)::
A space-separated string of diff options to use in the diff view.
git-show(1) is used for formatting and always passes --patch-with-stat.
Can control display of commit header metadata, passing option --format.
This option overrides any options specified in the TIG_DIFF_OPTS
environment variable (described in manpage:tig[1]), but is itself
overridden by diff flags given on the command line invocation.
'blame-options' (string)::
A space-separated string of default blame options. Can be used for
telling git-blame(1) how to detect the origin of lines. The options
are ignored when Tig is started in blame mode and given blame options
on the command line.
'log-options' (string)::
A space-separated string of default options that should be passed to the
git-log(1) command used by the log view. Options can be overridden by
command line options. Used internally to override custom `pretty.format'
settings that break the log view.
'main-options' (string)::
A space-separated string of default options that should be passed to the
git-log(1) command used by the main view. Options can be overridden by
command line options.
'reference-format' (string)::
A space-separated string of format strings used for formatting reference
names. Wrap the name of the reference type with the characters you would
like to use for formatting, e.g. `[tag]` and `<remote>`. If no format is
specified for `local-tag`, the format for `tag` is used. Similarly, if no
format is specified for `tracked-remote`, the format for `remote` is used,
and if no format is specified for any other reference type, the format for
`branch` is used.
Prefix with `hide:` to not show that reference type, e.g. `hide:remote`.
Supported reference types are:
- head : The current HEAD.
- tag : An annotated tag.
- local-tag : A lightweight tag.
- remote : A remote.
- tracked-remote : The remote tracked by current HEAD.
- replace : A replaced reference.
- branch : A branch.
- stash : The stash.
- note : Notes.
- prefetch : Refs prefetched by `git maintenance`.
- other : Any other reference.
'line-graphics' (mixed) [ascii|default|utf-8|auto|<bool>]::
What type of character graphics for line drawing. "auto" means "utf-8"
if the locale is UTF-8, "default" otherwise.
'truncation-delimiter' (mixed) [utf-8|<string>]::
A single character to draw where columns are truncated. The default is
"~". The special value "utf-8" refers to the character "โฏ"
("Midline Horizontal Ellipsis").
'horizontal-scroll' (mixed)::
Interval to scroll horizontally in each step. Can be specified either
as the number of columns, e.g. '5', or as a percentage of the view
width, e.g. '33%', where the maximum is 100%. For percentages it is
always ensured that at least one column is scrolled. The default is to
scroll '50%' of the view width.
'git-colors' (list)::
A space-separated list of "key=value" pairs where the key is a Git color
name and the value is a Tig color name, e.g. "branch.current=main-head"
and "grep.filename=grep.file". Set to "no" to disable.
'show-notes' (mixed) [<reference>|<bool>]::
Whether to show notes for a commit. When set to a note reference the
reference is passed to `git show --notes=`. Notes are enabled by
default.
'show-changes' (bool)::
Whether to show staged and unstaged changes in the main view.
'show-untracked' (bool)::
Whether to also show untracked changes in the main view.
'vertical-split' (mixed) [auto|<bool>]::
Whether to split the view horizontally or vertically.
"auto" (which is the default) means that it will depend on the window
dimensions. When true vertical orientation is used, and false sets the
orientation to horizontal.
'split-view-height' (mixed)::
The height of the bottom view in a horizontally split display. Can be
specified either as the number of rows, e.g. '5', or as a percentage of
the view height, e.g. '80%', where the maximum is 100%. It is always
ensured that the smaller of the views is at least four rows high. The
default is '67%'.
'split-view-width' (mixed)::
Width of the right-most view in a vertically split display. Can be
specified either as the number of columns, e.g. '5', or as a percentage
of the view width, e.g. '80%', where the maximum is 100%. It is always
ensured that the smaller of the views is at least four columns wide. The
default is '50%'.
'status-show-untracked-dirs' (bool)::
Show untracked directory contents in the status view (analogous to
`git ls-files --directory` option). On by default.
'status-show-untracked-files' (bool)::
Show untracked files in the status view (mirrors Git's
`status.showUntrackedFiles` option). On by default.
'tab-size' (int)::
Number of spaces per tab. The default is 8 spaces.
'diff-context' (int)::
Number of context lines to show for diffs.
'word-diff' (bool)::
Show a word diff. Only plain mode is supported. Off by default.
'diff-highlight' (mixed)::
Whether to highlight diffs using Git's 'diff-highlight' program. Defaults
to false. When set to true then 'diff-highlight' is used, else the option
value is used as the path. When this option is in effect, highlighted
regions are governed by `color diff-add-highlight` and
`color diff-del-highlight`.
'diff-indicator' (bool)::
Show +/- signs in the diff view. On by default.
'ignore-space' (mixed) [no|all|some|at-eol|<bool>]::
Ignore space changes in diff view. By default no space changes are
ignored. Changing this to "all", "some" or "at-eol" is equivalent to
passing "--ignore-all-space", "--ignore-space" or
"--ignore-space-at-eol" respectively to `git diff` or `git show`. +
+
*Warning:* when `ignore-space` is set to `some`, `all` or `at-eol`, then
the *status-update* and *status-revert* may fail when updating or
reverting chunks containing lines with space changes. Similarly,
*stage-update-line* may fail when updating a line adjacent to a line
with space changes.
'commit-order' (enum) [auto|default|topo|date|author-date|reverse]::
Commit ordering using the default (reverse chronological) order,
topological order, date order or reverse order. When set to "auto"
(which is the default), topological order is automatically used in the
main view when the commit graph is enabled. In repositories with a long
commit history it is advised to set this option to "default" to speed up
loading of the main view.
'ignore-case' (enum) [no|yes|smart-case]::
Ignore case in searches. "smart-case" ignores case if the search string
doesn't contain any uppercase letters. By default, the search is case
sensitive.
'mailmap' (bool)::
Read canonical name and email addresses for authors and committers from
`.mailmap`. Off by default. See `git-shortlog(1)`.
'wrap-lines' (bool)::
Wrap long lines. By default, lines are not wrapped.
Not compatible with line numbers enabled.
'wrap-search' (bool)::
Wrap around to top/bottom of view when searching. On by default.
'focus-child' (bool)::
Whether to focus the child view when it is opened. When disabled the
focus will remain in the parent view, avoiding reloads of the child
view when navigating the parent view. True by default.
'send-child-enter' (bool)::
Whether to send "enter" key presses to the child view, even if parent
view is active. When disabled the child view has to be explicitly
focused to receive the "enter" key presses. In practice only relevant
when `set focus-child = no`. True by default.
'editor-line-number' (bool)::
Whether to pass the selected line number to the editor command. The
line number is passed as `+<line-number>` in front of the file name.
Example: `vim +10 tig.c`
'history-size' (int)::
Size of the persistent `~/.tig_history` file when compiled with readline
support. Default is 500. Set to 0 to disable.
'mouse' (bool)::
Whether to enable mouse support. Off by default since it makes selecting
text from the terminal less intuitive. When enabled hold down Shift (or
Option on Mac) to select text. Mouse support requires that ncurses
itself support mouse events.
'mouse-scroll' (int)::
Interval to scroll up or down using the mouse. The default is 3 lines.
Mouse support requires that ncurses itself support mouse events and that
you have enabled mouse support in ~/.tigrc with `set mouse = true`.
'mouse-wheel-cursor' (bool)::
Whether to prefer moving the cursor to scrolling the view when using the
mouse wheel. Off by default. Combines well with `set mouse-scroll = 1`.
Mouse support requires that ncurses itself support mouse events and that
you have enabled mouse support in ~/.tigrc with `set mouse = true`.
'pager-autoscroll' (bool)::
Whether to automatically scroll the pager view while loading. Move the
cursor out of the last line to stop scrolling and back in to resume.
'recurse-tree' (bool)::
Whether to show all files recursively in the tree view.
'pgrp' (bool)::
Make tig the process-group leader when starting and clean all processes
when exiting. Off by default. Do not enable this option if you are
using a Zsh version affected by zsh-workers/43379. Run `xclip` with
`setsid` to keep clipboard content after exiting tig. If you are using
git-credential-cache helper, set option `credentialCache.ignoreSIGHUP`.
'start-on-head' (bool)::
Start with cursor on HEAD commit.
'refresh-mode' (mixed) [manual|auto|after-command|periodic|<bool>]::
Configures how views are refreshed based on modifications to watched
files in the repository. When set to 'manual', nothing is refreshed
automatically. When set to 'auto', views are refreshed when a
modification is detected in another view. When set to 'after-command'
only refresh after returning from an external command. When set to
'periodic', visible views are refreshed periodically using
'refresh-interval'.
'refresh-interval' (int)::
Interval in seconds between view refresh update checks when
'refresh-mode' is set to 'periodic'.
'file-args' (args)::
Command line arguments referring to files. These are filtered using
`git-rev-parse(1)`.
'rev-args' (args)::
Command line arguments referring to revisions. These are filtered using
`git-rev-parse(1)`.
View settings
~~~~~~~~~~~~~
The view settings define the order and options for the different columns of a
view. Each view setting expects a space-separated list of column specifications.
Column specifications start with the column type, and can optionally be
followed by a colon (`:`) and a list of column options. E.g. the following
column specification defines an 'author' column displaying the author email and
with a fixed width of 20 characters: `author:email,width=20`.
The first option value in a column specification is always the 'display' option.
When no 'display' value is given, 'yes' is assumed. For 'display' options
expecting an enumerated value this will automatically resolve to the default
enum value. For example, `file-name` will automatically have its 'display'
setting resolve to 'auto'.
Specifications can also be given for a single column, for example to override
the defaults in the system tigrc file. To override a single column, use the
column name as a suffix after the view setting name, e.g. `main-view-date` will
allow setting the date in the main view.
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
# Enable both ID and line numbers in the blame view
set blame-view = date:default author:full committer:no file-name:auto \
id:yes,color line-number:yes,interval=5 text
# Change grep view to be similar to `git grep` format
set grep-view = file-name:yes line-number:yes,interval=1 text
# Show file sizes as units
set tree-view = line-number:no,interval=5 mode author:full committer:no \
file-size:units date:default id:no file-name
# Show line numbers for every 10th line in the pager view
set pager-view = line-number:yes,interval=10 text
# Shorthands to change view settings for a previously defined column
set main-view-date = custom
set main-view-date-format = "%Y-%m-%d %H:%M"
set blame-view-line-number = no
# Use Git's default commit order, even when the commit graph is enabled.
set commit-order = default
--------------------------------------------------------------------------
The following list shows the available view settings and what column types
they support:
blob-view, diff-view, log-view, pager-view, stage-view:: line-number, text
blame-view:: author, committer, date, file-name, id, line-number, text
grep-view:: file-name, line-number, text
main-view, reflog-view:: author, committer, date, commit-title, id, line-number, ref
refs-view:: author, committer, date, commit-title, id, line-number, ref
stash-view:: author, date, commit-title, id, line-number
status-view:: file-name, line-number, status
tree-view:: author, committer, date, id, file-name, file-size, line-number, mode
Supported column types and their respective column options:
author, committer::
- 'display' (mixed) [full|abbreviated|email|email-user|<bool>]: How to
display author/committer names. If set to "abbreviated"
author/committer initials will be shown.
- 'width' (int): Fixed width for the column. When set to a value between
1 and 10, the author/committer name will be abbreviated to the
author/committer's initials.
When set to zero, the width is automatically sized to fit the content.
- 'maxwidth' (int): Maximum width of the column. Permit automatically
sizing content, up to this limit. Can be specified either as the number
of columns, e.g. '15', or as a percentage of the view width, e.g. '20%',
where the maximum is 100%.
commit-title::
- 'graph' (mixed) [no|v2|v1]: Whether to show the revision graph in the
main view on start-up. "v1" refers to the old graph rendering, which
is less accurate but faster and thus recommended in large
repositories. See also the 'line-graphics' option.
- 'refs' (bool): Whether to show references (branches, tags, and
remotes) in the main view. Can be toggled.
- 'overflow' (bool or int): Whether to highlight text in commit titles
exceeding a given width. When set to a boolean, it enables or disables
the highlighting using the default width of 50 characters. When set to
an int, the assigned value is used as the maximum character width.
date::
- 'display' (mixed) [relative|relative-compact|custom|default|<bool>]:
How to display dates. If set to "relative" or "relative-compact" a
relative date will be used, e.g. "2 minutes ago" or "2m". If set to
"custom", the strftime(3) string format specified in the "format"
option is used.
- 'use-author' (bool): Whether to show author date instead of committer
date.
- 'local' (bool): If true, use localtime(3) to convert to local
timezone. Note that relative dates always use local offsets.
- 'format' (string): format string to pass to strftime(3) when 'custom'
display mode has been selected.
- 'width' (int): Fixed width for the column. When set to zero, the width
is automatically sized to fit the content.
file-name::
- 'display' (mixed) [auto|always|<bool>]: When to display file names.
If set to "auto" file names are shown only when needed, e.g. when
running: tig blame -C <file>.
- 'width' (int): Width of the column. When set to zero, the width is
automatically sized to fit the content.
- 'maxwidth' (int): Maximum width of the column. Permit automatically
sizing content, up to this limit. Can be specified either as the number
of columns, e.g. '15', or as a percentage of the view width, e.g. '20%',
where the maximum is 100%.
file-size::
- 'display' (mixed) [default|units|<bool>]: How to display file sizes.
When set to "units", sizes are shown using binary prefixes, e.g. 12524
bytes is shown as "12.2K".
- 'width' (int): Fixed width for the filename column. When set to zero,
the width is automatically sized to fit the content.
id::
- 'display' (bool): Whether to show commit IDs in the main view.
- 'width' (int): Fixed width for the commit ID column. When unset Tig
will use the value of 'core.abbrev' if found. See git-config(1) on how
to set 'core.abbrev'. When set to zero the width is automatically sized
to fit the content of reflog (e.g. `ref/stash@{4}`) IDs and otherwise
defaults to 7.
line-number::
- 'display' (bool): Whether to show line numbers.
- 'interval' (int): Interval between line numbers.
- 'width' (int): Fixed width for the column. When set to zero, the width
is automatically sized to fit the content.
mode::
- 'display' (bool): Whether to show file modes.
- 'width' (int): Fixed width for the column. When set to zero, the width
is automatically sized to fit the content.
ref::
- 'display' (bool): Whether to show the reference name.
- 'width' (int): Fixed width for the column. When set to zero, the width
is automatically sized to fit the content.
- 'maxwidth' (int): Maximum width of the column. Permit automatically
sizing content, up to this limit. Can be specified either as the number
of columns, e.g. '15', or as a percentage of the view width, e.g. '20%',
where the maximum is 100%.
status::
- 'display' (mixed) [no|short|long|<bool>]: How to display the status
label.
text::
- 'commit-title-overflow' (bool or int): Whether to highlight commit
titles exceeding a given width in the diff view. When set to a
boolean, it enables or disables the highlighting using the default
width of 50 characters. When set to an int, the assigned value is used
as the maximum character width.
All column options can be toggled. For 'display' options, use the
option name as the prefix followed by a dash and the column name. E.g.
`:toggle author-display` will toggle the 'display' option in the 'author'
column. For all other options use the column name followed by a dash and
then the option name as the suffix. E.g. `:toggle commit-title-graph`
will toggle the 'graph' option in the 'commit-title' column. Alternatively,
use the option menu to manipulate options.
Bind command
------------
Using bind commands, keys can be mapped to an action when pressed in a given
key map. The syntax is:
[verse]
*bind* 'keymap' 'key' 'action'
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
# Add keybinding to quickly jump to the next diff chunk in the stage view
bind stage <Enter> :/^@@
# Disable the default mapping for running git-gc
bind generic G none
# User-defined external command to amend the last commit
bind status + !git commit --amend
# User-defined internal command that reloads ~/.tigrc
bind generic S :source ~/.tigrc
# UTF8-encoded characters can be used as key values.
bind generic รธ @sh -c "printf '%s' %(commit) | pbcopy"
--------------------------------------------------------------------------
Or in the Git configuration files:
// TEST: gitconfig
--------------------------------------------------------------------------
[tig "bind"]
# 'unbind' the default quit key binding
generic = Q none
# Cherry-pick current commit onto current branch
main = C !git cherry-pick %(commit)
--------------------------------------------------------------------------
Keys are mapped by first searching the keybindings for the current view, then
the keybindings for the *generic* keymap, and last the default keybindings.
Thus, the view keybindings override the generic keybindings which override the
built-in keybindings.
Clear keybinding (unbind) from all keymaps at once with bind *generic* 'key'
*none*.
Keybindings at the line-entry prompt are typically governed by the readline
library, and are configured separately in `~/.inputrc`. See 'readline(1)'.
Tig respects but does not require an `$if tig` section in `~/.inputrc`.
--
Keymaps::
Valid keymaps are: *main*, *diff*, *log*, *reflog*, *help*, *pager*, *status*,
*stage*, *tree*, *blob*, *blame*, *refs*, *stash*, *grep* and *generic*. Use
*generic* to set key mapping in all keymaps (which may still be overridden by a
specific view keybinding). Use *search* to define keys for navigating search
results during search.
Key values::
Key values should never be quoted. Use either an ASCII or UTF8-encoded character
or one of the following symbolic key names. Symbolic key names are case
insensitive and start with "<" and end with ">". Use *<Hash>* to bind to the
`#` key, since the hash mark is used as a comment character. Use *<LessThan>* to
bind to the `<` key.
*<Enter>*, *<Space>*, *<Backspace>*, *<Tab>*, *<Escape>* or *<Esc>*, *<Left>*,
*<Right>*, *<Up>*, *<Down>*, *<Insert>* or *<Ins>*, *<Delete>* or *<Del>*,
*<Hash>*, *<LessThan>* or *<LT>*, *<Home>*, *<End>*, *<PageUp>* or *<PgUp>*,
*<PageDown>* or *<PgDown>*, *<ScrollBack>* or *<SBack>*, *<ScrollFwd>* or
*<SFwd>*, *<ShiftTab>* or *<BackTab>*, *<ShiftLeft>*, *<ShiftRight>*,
*<ShiftDelete>* or *<ShiftDel>*, *<ShiftHome>*, *<ShiftEnd>*, *<SingleQuote>*,
*<DoubleQuote>*, *<F1>* ... *<F19>*
To define key mappings with the `Ctrl` key, use `<Ctrl-key>`. In addition, key
combos consisting of an initial `Escape` key followed by a normal key value can
be bound using `<Esc>key`.
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
bind main R refresh
bind main <Down> next
bind main <Ctrl-f> scroll-page-down
bind main <Esc>o options
bind main <ShiftTab> parent
--------------------------------------------------------------------------
Notes
- Tig reads keystrokes via ncurses and is subject to various limitations. See
'ncurses(3x)' and 'terminfo(5)' (or termcap).
- `Ctrl-m` and `Ctrl-i` cannot be bound as they conflict with 'Enter' and 'Tab'
respectively.
- Case differences cannot be distinguished in control sequences such as
`Ctrl-f` and `Ctrl-F`.
- `Ctrl-<Space>` is typically translated to `Ctrl-@`, which is available for
binding.
- Only some subset of special symbolic keys such as `<ShiftTab>` will be
available in any given terminal emulator.
- `Ctrl-z` is automatically used for process control and will suspend Tig and
open a subshell (use `fg` to reenter Tig).
Actions::
Actions are either specified as user-defined commands (external or internal) or
using action names as described in the following sections.
--
External user-defined command
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
These actions start with one or more of the following option flags followed by
the command that should be executed.
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|! |Run the command in the foreground with output shown.
|@ |Run the command in the background with no output.
|+ |Run the command synchronously, and echo the first line
of output to the status bar.
|? |Prompt the user before executing the command.
|< |Exit Tig after executing the command.
|> |Re-open Tig instantly in the last displayed view after
executing the command.
|=============================================================================
Unless otherwise specified, commands are run in the foreground with their
console output shown (as if '!' was specified). When multiple command options
are specified their behavior is combined, e.g. "?<git commit" will prompt the
user whether to execute the command and will exit Tig after completion.
Note that if you want to use pipes or redirection in your commands then you
must run them in a subshell, i.e. embed your commands in `sh -c '<commands>'`.
Browsing state variables
^^^^^^^^^^^^^^^^^^^^^^^^
User-defined commands can optionally refer to Tig's internal state using the
following variable names, which are substituted before commands are run:
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|%(head) |The currently viewed 'head' ID. Defaults to HEAD
|%(commit) |The currently selected commit ID.
|%(blob) |The currently selected blob ID.
|%(branch) |The currently selected branch name.
|%(remote) |The currently selected remote name. For remote
branches %(branch) will contain the branch name.
|%(tag) |The currently selected tag name.
|%(refname) |The currently selected reference name including the
remote name for remote branches.
|%(stash) |The currently selected stash name.
|%(directory) |The current directory path in the tree view or
"." if undefined.
|%(file) |The currently selected file.
|%(file_old) |The old filename of the currently selected file.
|%(lineno) |The currently selected line number. Defaults to 0.
|%(lineno_old) |The currently selected line number, before the diff
was applied. Defaults to 0.
|%(status) |The staging status of the currently selected line.
|%(ref) |The reference given to blame or HEAD if undefined.
|%(revargs) |The revision arguments passed on the command line.
|%(fileargs) |The file arguments passed on the command line.
|%(cmdlineargs) |All other options passed on the command line.
|%(diffargs) |Options from 'diff-options' or 'TIG_DIFF_OPTS' used
by the diff and stage view.
|%(blameargs) |Options from 'blame-options' used by the blame view.
|%(logargs) |Options from 'log-options' used by the log view.
|%(mainargs) |Options from 'main-options' used by the main view.
|%(prompt) |Prompt for the argument value. Optionally specify a
custom prompt using `"%(prompt Enter branch name: )"`
|%(text) |The text column of the currently selected line.
|%(repo:head) |The name of the checked out branch, e.g. `master`
|%(repo:head-id) |The commit ID of the checked out branch.
|%(repo:remote) |The remote name associated with the checked out
branch, e.g. `origin`.
|%(repo:upstream) |The upstream branch associated with the checked out
branch, e.g. `origin/master`.
|%(repo:cdup) |The path to change directory to the repository root,
e.g. `../`
|%(repo:prefix) |The path prefix of the current work directory,
e.g. `subdir/`.
|%(repo:git-dir) |The path to the Git directory, e.g. `/src/repo/.git`.
|%(repo:worktree) |The worktree path, if defined.
|%(repo:is-inside-work-tree)
|Whether Tig is running inside a work tree,
either `true` or `false`.
|=============================================================================
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
# Save the current commit as a patch file when the user selects a commit
# in the main view and presses 'S'.
bind main S !git format-patch -1 %(commit)
# Create and checkout a new branch; specify custom prompt
bind main B ?git checkout -b "%(prompt Enter new branch name: )"
# Show commit statistics for the author under the cursor
bind main U +sh -c 'git --no-pager shortlog -s --author="$(git show -s --format=%aE %(commit))" </dev/tty'
--------------------------------------------------------------------------
Advanced shell-like commands
^^^^^^^^^^^^^^^^^^^^^^^^^^^^
If your command requires use of dynamic features, such as subshells,
expansion of environment variables and process control, this can be achieved by
using a shell command:
.Configure a binding to copy the current commit ID to the clipboard.
// TEST: tigrc
--------------------------------------------------------------------------
bind generic I @sh -c "echo -n %(commit) | xclip -selection c"
--------------------------------------------------------------------------
Or by using a combination of Git aliases and Tig external commands. The
following example entries can be put in either the .gitconfig or .git/config
file:
.Git configuration which binds Tig keys to Git command aliases.
// TEST: gitconfig
--------------------------------------------------------------------------
[alias]
gitk-bg = !"gitk HEAD --not $(git rev-parse --remotes) &"
publish = !"for i in origin public; do git push $i; done"
[tig "bind"]
generic = V @git gitk-bg
generic = > !git publish
--------------------------------------------------------------------------
Internal user-defined commands
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
Actions beginning with a ':' will be run and interpreted as internal commands
and act similar to commands run via Tig's prompt. Valid internal commands are
configuration file options (as described in this document) and pager view
commands. Examples:
// TEST: tigrc
--------------------------------------------------------------------------
# Reload ~/.tigrc when 'S' is pressed
bind generic S :source .tigrc
# Change diff view to show all commit changes regardless of file limitations
bind diff F :set diff-options = --full-diff
# Show the output of git-reflog(1) in the pager view
bind generic W :!git reflog
# Search for previous diff (c)hunk and next diff header
bind stage 2 :?^@@
bind stage D :/^diff --(git|cc)
bind main I :toggle id # Show/hide the ID column
bind diff D :toggle diff-options --minimal # Use minimal diff algorithm
bind diff [ :toggle diff-context -3 # Decrease context (-U arg)
bind diff ] :toggle diff-context +3 # Increase context
bind generic V :toggle split-view-height -10% # Decrease split height
--------------------------------------------------------------------------
Similar to external commands, pager view commands can contain variable names
that will be substituted before the command is run.
Action names
~~~~~~~~~~~~
Valid action names are described below. Note, all action names are
case-insensitive, and you may use '-', '_', and '.' interchangeably, e.g.
"view-main", "View.Main", and "VIEW_MAIN" are the same.
ifndef::DOC_GEN_ACTIONS[]
View switching
^^^^^^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|view-main |Show main view
|view-diff |Show diff view
|view-log |Show log view
|view-reflog |Show reflog view
|view-tree |Show tree view
|view-blob |Show blob view
|view-blame |Show blame view
|view-refs |Show refs view
|view-status |Show status view
|view-stage |Show stage view
|view-stash |Show stash view
|view-grep |Show grep view
|view-pager |Show pager view
|view-help |Show help view
|=============================================================================
View manipulation
^^^^^^^^^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|enter |Enter and open selected line
|back |Go back to the previous view state
|next |Move to next
|previous |Move to previous
|parent |Move to parent
|view-next |Move focus to the next view
|refresh |Reload and refresh view
|maximize |Maximize the current view
|view-close |Close the current view
|view-close-no-quit |Close the current view without quitting
|quit |Close all views and quit
|=============================================================================
View-specific actions
^^^^^^^^^^^^^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|status-update |Stage/unstage chunk or file changes
|status-revert |Revert chunk or file changes
|status-merge |Merge file using external tool
|stage-update-line |Stage/unstage single line
|stage-update-part |Stage/unstage part of a chunk
|stage-split-chunk |Split current diff chunk
|=============================================================================
Cursor navigation
^^^^^^^^^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|move-up |Move cursor one line up
|move-down |Move cursor one line down
|move-page-up |Move cursor one page up
|move-page-down |Move cursor one page down
|move-half-page-up |Move cursor half a page up
|move-half-page-down |Move cursor half a page down
|move-first-line |Move cursor to first line
|move-last-line |Move cursor to last line
|move-next-merge |Move cursor to next merge commit
|move-prev-merge |Move cursor to previous merge commit
|=============================================================================
Scrolling
^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|scroll-line-up |Scroll one line up
|scroll-line-down |Scroll one line down
|scroll-page-up |Scroll one page up
|scroll-page-down |Scroll one page down
|scroll-half-page-up |Scroll half a page up
|scroll-half-page-down |Scroll half a page down
|scroll-first-col |Scroll to the first line columns
|scroll-left |Scroll two columns left
|scroll-right |Scroll two columns right
|=============================================================================
Searching
^^^^^^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|search |Search the view
|search-back |Search backwards in the view
|find-next |Find next search match
|find-prev |Find previous search match
|=============================================================================
Misc
^^^^
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|edit |Open in editor
|prompt |Open the prompt
|options |Open the options menu
|screen-redraw |Redraw the screen
|stop-loading |Stop all loading views
|show-version |Show version information
|none |Do nothing
|=============================================================================
endif::DOC_GEN_ACTIONS[]
Color command
-------------
Color commands control highlighting and the user interface styles. If your
terminal supports color and the NO_COLOR environment variable is unset
or empty, these commands can be used to assign foreground and background
combinations to certain areas. Optionally, an attribute can be given as
the last parameter. The syntax is:
[verse]
*color* 'area' 'fgcolor' 'bgcolor' '[attributes]'
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
# Override the default terminal colors to white on black.
color default white black
# Diff colors
color diff-header yellow default
color diff-index blue default
color diff-chunk magenta default
color "Reported-by:" green default
# View-specific color
color tree.date black cyan bold
# Custom color
color "/(note|warning|error):/" yellow default bold
--------------------------------------------------------------------------
Or in the Git configuration files:
// TEST: gitconfig
--------------------------------------------------------------------------
[tig "color"]
# A strange looking cursor line
cursor = red default underline
# UI colors
title-blur = white blue
title-focus = white blue bold
# View-specific color
[tig "color.tree"]
date = cyan default bold
--------------------------------------------------------------------------
Area names::
Can be either a built-in area name or a custom quoted string. The
latter allows custom color rules to be added for lines matching a
quoted string. Strings of the form "/.../" are interpreted as
regular expressions.
Valid built-in area names are described below. Note, all names are
case-insensitive, and you may use '-' and '_' interchangeably,
e.g. "Diff-Header" and "DIFF_HEADER" are the same.
View-specific colors can be defined by prefixing the view name to
the area name, e.g. "stage.diff-chunk" and "diff.diff-chunk".
Color names::
Valid colors include: *white*, *black*, *green*, *magenta*, *blue*,
*cyan*, *yellow*, *red*, *default*. Use *default* to refer to the
default terminal colors, for example, to keep the background
transparent when you are using a terminal with a transparent
background.
+
Colors can also be specified using the keywords *color0*, *color1*, ...,
*colorN-1* (where *N* is the number of colors supported by your terminal).
This is useful when you remap the colors for your display or want to enable
colors supported by 88-color and 256-color terminals. Note that the 'color'
prefix is optional. If you prefer, you can specify colors directly by their
numbers *0*, *1*, ..., *N-1* instead, just like in the configuration file of
Git.
Attribute names::
Valid attributes include: *normal*, *blink*, *bold*, *dim*, *reverse*,
*standout*, and *underline*. Note, not all attributes may be supported
by the terminal.
UI colors
~~~~~~~~~
The colors and attributes to be used for the text that is not highlighted or
that specify the use of the default terminal colors can be controlled by
setting the *default* color option.
.General
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|default |Override default terminal colors (see above).
|cursor |The cursor line for the current view.
|cursor-blur |The cursor line of any backgrounded view.
|status |The status window showing info messages.
|title-focus |The title window for the current view.
|title-blur |The title window of any backgrounded view.
|search-result |Highlighted search result.
|delimiter |Delimiter shown for truncated lines.
|header |The view header lines. Use 'status.header' to color
the staged, unstaged, and untracked sections in the
status view. Use 'help.header' to color the keymap
sections in the help view.
|line-number |Line numbers.
|id |The commit ID.
|date |The committer date or author date.
|author |The commit author.
|committer |The committer.
|mode |The file mode holding the permissions and type.
|overflow |Title text overflow.
|directory |The directory name.
|file |The file name.
|file-size |File size.
|=============================================================================
.Main view colors
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|graph-commit |The commit dot in the revision graph.
|palette-[0-13] |14 different colors, used for distinguishing branches
or commits. By default, the palette uses the ASCII
colors, where the second half of them have the bold
attribute enabled to give a brighter color.
Example: palette-0 = red
|main-commit |The commit comment.
|main-annotated |The commit comment of an annotated commit.
|main-head |Label of the current branch.
|main-remote |Label of a remote.
|main-tracked |Label of the remote tracked by the current branch.
|main-tag |Label of a signed tag.
|main-local-tag |Label of a local tag.
|main-ref |Label of a branch.
|main-replace |Label of replaced reference.
|main-stash |Label of the stash.
|main-note |Label of notes.
|main-prefetch |Label of reference prefetched by `git maintenance`.
|main-other |Label of any other reference.
|=============================================================================
.Status view
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|stat-none |Empty status label.
|stat-staged |Status flag of staged files.
|stat-unstaged |Status flag of unstaged files.
|stat-untracked |Status flag of untracked files.
|=============================================================================
.Help view
[frame="none",grid="none",cols="25<m,75<"]
|=============================================================================
|help-group |Help group name.
|help-action |Help action name.
|=============================================================================
Highlighting
~~~~~~~~~~~~
--
Diff markup::
Options concerning diff start, chunks and lines added and deleted.
*diff-header*, *diff-chunk*, *diff-stat*, *diff-add*, *diff-add2*,
*diff-del*, *diff-del2*, *diff-add-highlight*, *diff-del-highlight*
Enhanced Git diff markup::
Extra diff information emitted by the Git diff machinery, such as mode
changes, rename detection, and similarity.
*diff-oldmode*, *diff-newmode*, *diff-copy-from*, *diff-copy-to*,
*diff-similarity*, *diff-index*
Pretty print commit headers::
Commit diffs and the revision logs are usually formatted using pretty printed
headers, unless `--pretty=raw` was given. This includes lines, such as merge
info, commit ID, and author and committer date.
*pp-refs*, *pp-reflog*, *pp-reflogmsg*, *pp-merge*
Raw commit header::
Usually shown when `--pretty=raw` is given, however 'commit' is pretty much
omnipresent.
*commit*, *parent*, *tree*, *author*, *committer*
Commit message::
Most common trailer lines (e.g. `Signed-off-by`) are colorized.
Characters in the commit title exceeding a predefined width can be highlighted.
Tree markup::
Colors for information of the tree view.
*tree-dir*, *tree-file*
--
Source command
-------------
Source commands make it possible to read additional configuration files.
Sourced files are included in-place, meaning when a 'source' command is
encountered the file will be immediately read. Any commands later in the
current configuration file will take precedence.
If the given path does not exist, tig will proceed with a warning. Give
the `-q` parameter to suppress the warning.
The syntax is:
[verse]
*source* '[-q]' 'path'
Examples:
// TEST: tigrc
--------------------------------------------------------------------------
source ~/.tig/colorscheme.tigrc
source ~/.tig/keybindings.tigrc
--------------------------------------------------------------------------
COPYRIGHT
---------
Copyright (c) 2006-2026 Jonas Fonseca <[email protected]>
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
SEE ALSO
--------
ifndef::backend-docbook[]
link:tig.1.{docext}[tig(1)],
link:manual.{docext}[the Tig manual],
endif::backend-docbook[]
ifdef::backend-docbook[]
manpage:tig[1],
manpage:tigmanual[7],
endif::backend-docbook[]
git(1), git-config(1)
// vim: tw=80
---
--- METRICS ---
- Files Extracted: 4
- Estimated Token Budget: ~20952 tokens
- Canonical Reference: https://codewiki.google/github.com/jonas/tig